Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrCannotCreateIndex Fired if the index is not created ErrCannotCreateIndex = fmt.Errorf("cannot create index") )
Functions ¶
This section is empty.
Types ¶
type ElasticHook ¶
type ElasticHook struct {
// contains filtered or unexported fields
}
ElasticHook is a logrus hook for ElasticSearch
func NewElasticHook ¶
func NewElasticHook(client *elasticsearch.Client, host string, levels []logrus.Level, index string) (*ElasticHook, error)
NewElasticHook creates new hook. client - ElasticSearch client with specific es version (v5/v6/v7/...) host - host of system level - log level index - name of the index in ElasticSearch
func NewElasticHookWithFunc ¶
func NewElasticHookWithFunc(client *elasticsearch.Client, host string, levels []logrus.Level, indexFunc IndexNameFunc) (*ElasticHook, error)
NewElasticHookWithFunc creates new hook with function that provides the index name. This is useful if the index name is somehow dynamic especially based on time. client - ElasticSearch client with specific es version (v5/v6/v7/...) host - host of system level - log level indexFunc - function providing the name of index
func (*ElasticHook) Fire ¶
func (hook *ElasticHook) Fire(entry *logrus.Entry) error
Fire is required to implement Logrus hook
func (*ElasticHook) Levels ¶
func (hook *ElasticHook) Levels() []logrus.Level
Levels Required for logrus hook implementation
Click to show internal directories.
Click to hide internal directories.